<p align="center"><img src="docs/source/images/syssimpymmen_logo.png" alt="SysSimPyMMEN" width="300"/></p>

# SysSimPyMMEN

Inferring the minimum-mass extrasolar nebula (MMEN) from the SysSim models.

For installation instructions, tutorials, and detailed documentation, [read the documentation](https://syssimpymmen.readthedocs.io/).
